@@ -1,34 +1,35 @@
 import asyncio
+import weakref
 from bisect import bisect
 from operator import add
 from time import time
-import weakref
 
-from bokeh.layouts import row, column
+from bokeh.layouts import column, row
 from bokeh.models import (
-    ColumnDataSource,
-    Plot,
-    DataRange1d,
-    LinearAxis,
-    HoverTool,
     BoxZoomTool,
-    ResetTool,
-    PanTool,
-    WheelZoomTool,
-    Range1d,
-    Quad,
-    TapTool,
-    OpenURL,
     Button,
+    ColumnDataSource,
+    DataRange1d,
+    HoverTool,
+    LinearAxis,
+    OpenURL,
+    PanTool,
+    Plot,
+    Quad,
+    Range1d,
+    ResetTool,
     Select,
+    TapTool,
+    WheelZoomTool,
 )
 from bokeh.palettes import Spectral9
 from bokeh.plotting import figure
-import dask
 from tornado import gen
 
-from distributed.dashboard.utils import without_property_validation, BOKEH_VERSION
+import dask
+
 from distributed import profile
+from distributed.dashboard.utils import BOKEH_VERSION, without_property_validation
 from distributed.utils import log_errors, parse_timedelta
 
 if dask.config.get("distributed.dashboard.export-tool"):
@@ -42,7 +43,7 @@ profile_interval = parse_timedelta(profile_interval, default="ms")
 
 
 class DashboardComponent:
-    """ Base class for Dask.distributed UI dashboard components.
+    """Base class for Dask.distributed UI dashboard components.
 
     This class must have two attributes, ``root`` and ``source``, and one
     method ``update``:
@@ -62,7 +63,7 @@ class DashboardComponent:
 
 
 def add_periodic_callback(doc, component, interval):
-    """ Add periodic callback to doc in a way that avoids reference cycles
+    """Add periodic callback to doc in a way that avoids reference cycles
 
     If we instead use ``doc.add_periodic_callback(component.update, 100)`` then
     the component stays in memory as a reference cycle because its method is
