@@ -2,48 +2,46 @@ import logging
 import math
 import os
 
-from bokeh.layouts import row, column, widgetbox
+from bokeh.layouts import column, row
 from bokeh.models import (
+    BoxZoomTool,
     ColumnDataSource,
     DataRange1d,
     HoverTool,
-    BoxZoomTool,
-    ResetTool,
-    PanTool,
-    WheelZoomTool,
     NumeralTickFormatter,
+    PanTool,
+    ResetTool,
     Select,
+    WheelZoomTool,
 )
-
 from bokeh.models.widgets import DataTable, TableColumn
-from bokeh.plotting import figure
 from bokeh.palettes import RdBu
+from bokeh.plotting import figure
 from bokeh.themes import Theme
-from dask.utils import format_bytes
 from tlz import merge, partition_all
 
+from dask.utils import format_bytes
+
 from distributed.dashboard.components import add_periodic_callback
 from distributed.dashboard.components.shared import (
     DashboardComponent,
-    ProfileTimePlot,
     ProfileServer,
+    ProfileTimePlot,
     SystemMonitor,
 )
-from distributed.dashboard.utils import transpose, without_property_validation, update
+from distributed.dashboard.utils import transpose, update, without_property_validation
 from distributed.diagnostics.progress_stream import color_of
 from distributed.metrics import time
-from distributed.utils import log_errors, key_split, format_time
-
+from distributed.utils import format_time, key_split, log_errors
 
 logger = logging.getLogger(__name__)
 
-with open(os.path.join(os.path.dirname(__file__), "..", "templates", "base.html")) as f:
-    template_source = f.read()
-
 from jinja2 import Environment, FileSystemLoader
 
 env = Environment(
-    loader=FileSystemLoader(os.path.join(os.path.dirname(__file__), "..", "templates"))
+    loader=FileSystemLoader(
+        os.path.join(os.path.dirname(__file__), "..", "..", "http", "templates")
+    )
 )
 
 BOKEH_THEME = Theme(os.path.join(os.path.dirname(__file__), "..", "theme.yaml"))
@@ -73,9 +71,9 @@ class StateTable(DashboardComponent):
             w = self.worker
             d = {
                 "Stored": [len(w.data)],
-                "Executing": ["%d / %d" % (len(w.executing), w.nthreads)],
+                "Executing": ["%d / %d" % (w.executing_count, w.nthreads)],
                 "Ready": [len(w.ready)],
-                "Waiting": [len(w.waiting_for_data)],
+                "Waiting": [w.waiting_for_data_count],
                 "Connections": [len(w.in_flight_workers)],
                 "Serving": [len(w._comms)],
             }
@@ -266,7 +264,7 @@ class ExecutingTimeSeries(DashboardComponent):
     def update(self):
         with log_errors():
             self.source.stream(
-                {"x": [time() * 1000], "y": [len(self.worker.executing)]}, 1000
+                {"x": [time() * 1000], "y": [self.worker.executing_count]}, 1000
             )
 
 
@@ -300,11 +298,6 @@ class CrossFilter(DashboardComponent):
             self.y = Select(title="Y-Axis", value="bandwidth", options=quantities)
             self.y.on_change("value", self.update_figure)
 
-            self.size = Select(
-                title="Size", value="None", options=["None"] + quantities
-            )
-            self.size.on_change("value", self.update_figure)
-
             self.color = Select(
                 title="Color", value="inout-color", options=["black"] + colors
             )
@@ -315,9 +308,7 @@ class CrossFilter(DashboardComponent):
             else:
                 kw = {}
 
-            self.control = widgetbox(
-                [self.x, self.y, self.size, self.color], width=200, **kw
-            )
+            self.control = column([self.x, self.y, self.color], width=200, **kw)
 
             self.last_outgoing = 0
             self.last_incoming = 0
@@ -369,11 +360,6 @@ class CrossFilter(DashboardComponent):
     def create_figure(self, **kwargs):
         with log_errors():
             fig = figure(title="", tools="", **kwargs)
-
-            size = self.size.value
-            if size == "None":
-                size = 1
-
             fig.circle(
                 source=self.source,
                 x=self.x.value,
