@@ -1,12 +1,15 @@
 import collections
+import logging
 import math
 
-from tornado.ioloop import IOLoop, PeriodicCallback
 import tlz as toolz
+from tornado.ioloop import IOLoop, PeriodicCallback
 
 from ..metrics import time
 from ..utils import parse_timedelta
 
+logger = logging.getLogger(__name__)
+
 
 class AdaptiveCore:
     """
@@ -78,10 +81,13 @@ class AdaptiveCore:
         self.periodic_callback = None
 
         def f():
-            self.periodic_callback = PeriodicCallback(self.adapt, self.interval * 1000)
-            self.periodic_callback.start()
+            try:
+                self.periodic_callback.start()
+            except AttributeError:
+                pass
 
         if self.interval:
+            self.periodic_callback = PeriodicCallback(self.adapt, self.interval * 1000)
             try:
                 self.loop.add_callback(f)
             except AttributeError:
@@ -100,6 +106,8 @@ class AdaptiveCore:
         self.log = collections.deque(maxlen=10000)
 
     def stop(self):
+        logger.info("Adaptive stop")
+
         if self.periodic_callback:
             self.periodic_callback.stop()
             self.periodic_callback = None
@@ -192,7 +200,9 @@ class AdaptiveCore:
                 await self.scale_up(**recommendations)
             if status == "down":
                 await self.scale_down(**recommendations)
-        except OSError:
-            self.stop()
+        except OSError as e:
+            if status != "down":
+                logger.error("Adaptive stopping due to error %s", str(e))
+                self.stop()
         finally:
             self._adapting = False
