@@ -1,10 +1,8 @@
 import logging
 
-from .plugin import SchedulerPlugin
-
-from ..core import connect, coerce_to_address
+from ..core import coerce_to_address, connect
 from ..worker import dumps_function
-
+from .plugin import SchedulerPlugin
 
 logger = logging.getLogger(__name__)
 
@@ -34,7 +32,7 @@ def teardown(scheduler, es):
 
 
 async def eventstream(address, interval):
-    """ Open a TCP connection to scheduler, receive batched task messages
+    """Open a TCP connection to scheduler, receive batched task messages
 
     The messages coming back are lists of dicts.  Each dict is of the following
     form::
