@@ -1,13 +1,14 @@
 import asyncio
-from collections import defaultdict
 import logging
+from collections import defaultdict
 from timeit import default_timer
 
-from toolz import groupby, valmap
+from tlz import groupby, valmap
 
+from dask.utils import stringify
+
+from ..utils import key_split, key_split_group, log_errors
 from .plugin import SchedulerPlugin
-from ..utils import key_split, key_split_group, log_errors, tokey
-
 
 logger = logging.getLogger(__name__)
 
@@ -40,7 +41,7 @@ def dependent_keys(tasks, complete=False):
 
 
 class Progress(SchedulerPlugin):
-    """ Tracks progress of a set of keys or futures
+    """Tracks progress of a set of keys or futures
 
     On creation we provide a set of keys or futures that interest us as well as
     a scheduler.  We traverse through the scheduler's dependencies to find all
@@ -61,7 +62,7 @@ class Progress(SchedulerPlugin):
 
     def __init__(self, keys, scheduler, minimum=0, dt=0.1, complete=False):
         self.keys = {k.key if hasattr(k, "key") else k for k in keys}
-        self.keys = {tokey(k) for k in self.keys}
+        self.keys = {stringify(k) for k in self.keys}
         self.scheduler = scheduler
         self.complete = complete
         self._minimum = minimum
@@ -130,7 +131,7 @@ class Progress(SchedulerPlugin):
 
 
 class MultiProgress(Progress):
-    """ Progress variant that keeps track of different groups of keys
+    """Progress variant that keeps track of different groups of keys
 
     See Progress for most details.  This only adds a function ``func=``
     that splits keys.  This defaults to ``key_split`` which aligns with naming
@@ -249,7 +250,7 @@ class AllProgress(SchedulerPlugin):
             prefix = ts.prefix.name
             self.all[prefix].add(key)
             self.state[ts.state][prefix].add(key)
-            if ts.nbytes is not None:
+            if ts.nbytes >= 0:
                 self.nbytes[prefix] += ts.nbytes
 
         scheduler.add_plugin(self)
@@ -263,11 +264,11 @@ class AllProgress(SchedulerPlugin):
         except KeyError:  # TODO: remove me once we have a new or clean state
             pass
 
-        if start == "memory":
+        if start == "memory" and ts.nbytes >= 0:
             # XXX why not respect DEFAULT_DATA_SIZE?
-            self.nbytes[prefix] -= ts.nbytes or 0
-        if finish == "memory":
-            self.nbytes[prefix] += ts.nbytes or 0
+            self.nbytes[prefix] -= ts.nbytes
+        if finish == "memory" and ts.nbytes >= 0:
+            self.nbytes[prefix] += ts.nbytes
 
         if finish != "forgotten":
             self.state[finish][prefix].add(key)
@@ -303,7 +304,7 @@ class GroupProgress(SchedulerPlugin):
                 self.create(key, k)
             self.keys[k].add(key)
             self.groups[k][ts.state] += 1
-            if ts.state == "memory" and ts.nbytes is not None:
+            if ts.state == "memory" and ts.nbytes >= 0:
                 self.nbytes[k] += ts.nbytes
 
         scheduler.add_plugin(self)
@@ -346,9 +347,9 @@ class GroupProgress(SchedulerPlugin):
                     for dep in self.dependencies.pop(k):
                         self.dependents[key_split_group(dep)].remove(k)
 
-            if start == "memory" and ts.nbytes is not None:
+            if start == "memory" and ts.nbytes >= 0:
                 self.nbytes[k] -= ts.nbytes
-            if finish == "memory" and ts.nbytes is not None:
+            if finish == "memory" and ts.nbytes >= 0:
                 self.nbytes[k] += ts.nbytes
 
     def restart(self, scheduler):
