@@ -1,20 +1,18 @@
-from contextlib import suppress
-import logging
 import html
-from timeit import default_timer
+import logging
 import sys
 import weakref
+from contextlib import suppress
+from timeit import default_timer
 
 from tlz import valmap
 from tornado.ioloop import IOLoop
 
-from .progress import format_time, Progress, MultiProgress
-
-from ..core import connect, coerce_to_address, CommClosedError
 from ..client import default_client, futures_of
+from ..core import CommClosedError, coerce_to_address, connect
 from ..protocol.pickle import dumps
-from ..utils import key_split, is_kernel, LoopRunner, parse_timedelta
-
+from ..utils import LoopRunner, is_kernel, key_split, parse_timedelta
+from .progress import MultiProgress, Progress, format_time
 
 logger = logging.getLogger(__name__)
 
@@ -160,7 +158,7 @@ class ProgressWidget(ProgressBar):
     ):
         super().__init__(keys, scheduler, interval, complete)
 
-        from ipywidgets import FloatProgress, HBox, VBox, HTML
+        from ipywidgets import HTML, FloatProgress, HBox, VBox
 
         self.elapsed_time = HTML("")
         self.bar = FloatProgress(min=0, max=1, description="")
@@ -256,8 +254,7 @@ class MultiProgressBar:
             return result
 
         self.comm = await connect(
-            self.scheduler,
-            connection_args=self.client().connection_args if self.client else None,
+            self.scheduler, **(self.client().connection_args if self.client else {})
         )
         logger.debug("Progressbar Connected to scheduler")
 
@@ -320,7 +317,7 @@ class MultiProgressWidget(MultiProgressBar):
         self.widget = VBox([])
 
     def make_widget(self, all):
-        from ipywidgets import FloatProgress, HBox, VBox, HTML
+        from ipywidgets import HTML, FloatProgress, HBox, VBox
 
         self.elapsed_time = HTML("")
         self.bars = {key: FloatProgress(min=0, max=1, description="") for key in all}
@@ -406,13 +403,13 @@ def progress(*futures, notebook=None, multi=True, complete=True, **kwargs):
 
     Parameters
     ----------
-    futures: Futures
+    futures : Futures
         A list of futures or keys to track
-    notebook: bool (optional)
+    notebook : bool (optional)
         Running in the notebook or not (defaults to guess)
-    multi: bool (optional)
+    multi : bool (optional)
         Track different functions independently (defaults to True)
-    complete: bool (optional)
+    complete : bool (optional)
         Track all keys (True) or only keys that have not yet run (False)
         (defaults to True)
 
