@@ -5,8 +5,14 @@ import pytest
 from distributed import Scheduler, Worker
 from distributed.diagnostics.progressbar import TextProgressBar, progress
 from distributed.metrics import time
-from distributed.utils_test import inc, div, gen_cluster
-from distributed.utils_test import client, loop, cluster_fixture  # noqa: F401
+from distributed.utils_test import (  # noqa: F401
+    client,
+    cluster_fixture,
+    div,
+    gen_cluster,
+    inc,
+    loop,
+)
 
 
 def test_text_progressbar(capsys, client):
@@ -25,17 +31,17 @@ def test_text_progressbar(capsys, client):
 
 
 @gen_cluster(client=True)
-def test_TextProgressBar_error(c, s, a, b):
+async def test_TextProgressBar_error(c, s, a, b):
     x = c.submit(div, 1, 0)
 
     progress = TextProgressBar([x.key], scheduler=s.address, start=False, interval=0.01)
-    yield progress.listen()
+    await progress.listen()
 
     assert progress.status == "error"
     assert progress.comm.closed()
 
     progress = TextProgressBar([x.key], scheduler=s.address, start=False, interval=0.01)
-    yield progress.listen()
+    await progress.listen()
     assert progress.status == "error"
     assert progress.comm.closed()
 
