@@ -1,18 +1,17 @@
 import asyncio
-from collections import defaultdict, deque
 import logging
 import uuid
+from collections import defaultdict, deque
 
 from .client import Client
-from .utils import log_errors, TimeoutError
+from .utils import TimeoutError, log_errors, parse_timedelta
 from .worker import get_worker
-from .utils import parse_timedelta
 
 logger = logging.getLogger(__name__)
 
 
 class LockExtension:
-    """ An extension for the scheduler to manage Locks
+    """An extension for the scheduler to manage Locks
 
     This adds the following routes to the scheduler
 
@@ -31,7 +30,7 @@ class LockExtension:
 
         self.scheduler.extensions["locks"] = self
 
-    async def acquire(self, stream=None, name=None, id=None, timeout=None):
+    async def acquire(self, comm=None, name=None, id=None, timeout=None):
         with log_errors():
             if isinstance(name, list):
                 name = tuple(name)
@@ -59,7 +58,7 @@ class LockExtension:
                 self.ids[name] = id
             return result
 
-    def release(self, stream=None, name=None, id=None):
+    def release(self, comm=None, name=None, id=None):
         with log_errors():
             if isinstance(name, list):
                 name = tuple(name)
@@ -73,7 +72,7 @@ class LockExtension:
 
 
 class Lock:
-    """ Distributed Centralized Lock
+    """Distributed Centralized Lock
 
     Parameters
     ----------
@@ -104,7 +103,7 @@ class Lock:
         self._locked = False
 
     def acquire(self, blocking=True, timeout=None):
-        """ Acquire the lock
+        """Acquire the lock
 
         Parameters
         ----------
