@@ -1,18 +1,18 @@
-from contextlib import suppress
 import logging
 import warnings
 import weakref
+from contextlib import suppress
 
-from tornado.httpserver import HTTPServer
 import tlz
+from tornado.httpserver import HTTPServer
+
 import dask
 
-from .comm import get_tcp_server_address
-from .comm import get_address_host
+from .comm import get_address_host, get_tcp_server_address
 from .core import Server
 from .http.routing import RoutingApplication
-from .versions import get_versions
 from .utils import DequeHandler, clean_dashboard_address
+from .versions import get_versions
 
 
 class ServerNode(Server):
@@ -121,7 +121,7 @@ class ServerNode(Server):
         self.http_server = HTTPServer(self.http_application, ssl_options=ssl_options)
         http_address = clean_dashboard_address(dashboard_address or default_port)
 
-        if not http_address["address"]:
+        if http_address["address"] is None:
             address = self._start_address
             if isinstance(address, (list, tuple)):
                 address = address[0]
