@@ -25,20 +25,20 @@ We represent this tree as a nested dictionary with the following form:
     }
 """
 import bisect
-from collections import defaultdict, deque
 import linecache
 import sys
 import threading
+from collections import defaultdict, deque
 from time import sleep
 
 import tlz as toolz
 
 from .metrics import time
-from .utils import format_time, color_of, parse_timedelta
+from .utils import color_of, format_time, parse_timedelta
 
 
 def identifier(frame):
-    """ A string identifier from a frame
+    """A string identifier from a frame
 
     Strings are cheaper to use as indexes into dicts than tuples or dicts
     """
@@ -74,7 +74,7 @@ def info_frame(frame):
 
 
 def process(frame, child, state, stop=None, omit=None):
-    """ Add counts from a frame stack onto existing state
+    """Add counts from a frame stack onto existing state
 
     This recursively adds counts to the existing state dictionary and creates
     new entries for new functions.
@@ -157,7 +157,7 @@ def create():
 
 
 def call_stack(frame):
-    """ Create a call text stack from a frame
+    """Create a call text stack from a frame
 
     Returns
     -------
@@ -171,7 +171,7 @@ def call_stack(frame):
 
 
 def plot_data(state, profile_interval=0.010):
-    """ Convert a profile state into data useful by Bokeh
+    """Convert a profile state into data useful by Bokeh
 
     See Also
     --------
@@ -277,23 +277,23 @@ def watch(
     omit=None,
     stop=lambda: False,
 ):
-    """ Gather profile information on a particular thread
+    """Gather profile information on a particular thread
 
     This starts a new thread to watch a particular thread and returns a deque
     that holds periodic profile information.
 
     Parameters
     ----------
-    thread_id: int
-    interval: str
+    thread_id : int
+    interval : str
         Time per sample
-    cycle: str
+    cycle : str
         Time per refreshing to a new profile state
-    maxlen: int
+    maxlen : int
         Passed onto deque, maximum number of periods
-    omit: str
+    omit : str
         Don't include entries that start with this filename
-    stop: callable
+    stop : callable
         Function to call to see if we should stop
 
     Returns
@@ -324,16 +324,16 @@ def watch(
 
 
 def get_profile(history, recent=None, start=None, stop=None, key=None):
-    """ Collect profile information from a sequence of profile states
+    """Collect profile information from a sequence of profile states
 
     Parameters
     ----------
-    history: Sequence[Tuple[time, Dict]]
+    history : Sequence[Tuple[time, Dict]]
         A list or deque of profile states
-    recent: dict
+    recent : dict
         The most recent accumulating state
-    start: time
-    stop: time
+    start : time
+    stop : time
     """
     now = time()
     if start is None:
@@ -366,7 +366,7 @@ def get_profile(history, recent=None, start=None, stop=None, key=None):
 
 
 def plot_figure(data, **kwargs):
-    """ Plot profile data using Bokeh
+    """Plot profile data using Bokeh
 
     This takes the output from the function ``plot_data`` and produces a Bokeh
     figure
@@ -375,8 +375,8 @@ def plot_figure(data, **kwargs):
     --------
     plot_data
     """
-    from bokeh.plotting import ColumnDataSource, figure
     from bokeh.models import HoverTool
+    from bokeh.plotting import ColumnDataSource, figure
 
     if "states" in data:
         data = toolz.dissoc(data, "states")
@@ -444,7 +444,7 @@ def _remove_py_stack(frames):
 
 
 def llprocess(frames, child, state):
-    """ Add counts from low level profile information onto existing state
+    """Add counts from low level profile information onto existing state
 
     This uses the ``stacktrace`` module to collect low level stack trace
     information and place it onto the given sttate.
