@@ -1,25 +1,18 @@
-from array import array
-from functools import partial
-import traceback
 import importlib
+import traceback
+from array import array
 from enum import Enum
+from functools import partial
+
+import msgpack
 
 import dask
 from dask.base import normalize_token
 
-import msgpack
-
+from ..utils import ensure_bytes, has_keyword, typename
 from . import pickle
-from ..utils import has_keyword, nbytes, typename, ensure_bytes, is_writeable
-from .compression import maybe_compress, decompress
-from .utils import (
-    unpack_frames,
-    pack_frames_prelude,
-    frame_split_size,
-    merge_frames,
-    msgpack_opts,
-)
-
+from .compression import decompress, maybe_compress
+from .utils import frame_split_size, msgpack_opts, pack_frames_prelude, unpack_frames
 
 lazy_registrations = {}
 
@@ -30,7 +23,7 @@ _cached_allowed_modules = {}
 
 
 def dask_dumps(x, context=None):
-    """Serialise object using the class-based registry"""
+    """Serialize object using the class-based registry"""
     type_name = typename(type(x))
     try:
         dumps = dask_serialize.dispatch(type(x))
@@ -54,7 +47,6 @@ def dask_loads(header, frames):
 
 
 def pickle_dumps(x, context=None):
-    header = {"serializer": "pickle"}
     frames = [None]
     buffer_callback = lambda f: frames.append(memoryview(f))
     frames[0] = pickle.dumps(
@@ -62,12 +54,35 @@ def pickle_dumps(x, context=None):
         buffer_callback=buffer_callback,
         protocol=context.get("pickle-protocol", None) if context else None,
     )
+    header = {
+        "serializer": "pickle",
+        "writeable": tuple(not f.readonly for f in frames[1:]),
+    }
     return header, frames
 
 
 def pickle_loads(header, frames):
     x, buffers = frames[0], frames[1:]
-    return pickle.loads(x, buffers=buffers)
+
+    writeable = header.get("writeable")
+    if not writeable:
+        writeable = len(buffers) * (None,)
+
+    new = []
+    memoryviews = map(memoryview, buffers)
+    for w, mv in zip(writeable, memoryviews):
+        if w == mv.readonly:
+            if mv.readonly:
+                mv = memoryview(bytearray(mv))
+            else:
+                mv = memoryview(bytes(mv))
+            if mv.nbytes > 0:
+                mv = mv.cast(mv.format, mv.shape)
+            else:
+                mv = mv.cast(mv.format)
+        new.append(mv)
+
+    return pickle.loads(x, buffers=new)
 
 
 def import_allowed_module(name):
@@ -374,6 +389,72 @@ def deserialize(header, frames, deserializers=None):
     return loads(header, frames)
 
 
+def serialize_and_split(x, serializers=None, on_error="message", context=None):
+    """Serialize and split compressable frames
+
+    This function is a drop-in replacement of `serialize()` that calls `serialize()`
+    followed by `frame_split_size()` on frames that should be compressed.
+
+    Use `merge_and_deserialize()` to merge and deserialize the frames back.
+
+    See Also
+    --------
+    serialize
+    merge_and_deserialize
+    """
+    header, frames = serialize(x, serializers, on_error, context)
+    num_sub_frames = []
+    offsets = []
+    out_frames = []
+    out_compression = []
+    for frame, compression in zip(
+        frames, header.get("compression") or [None] * len(frames)
+    ):
+        if compression is None:  # default behavior
+            sub_frames = frame_split_size(frame)
+            num_sub_frames.append(len(sub_frames))
+            offsets.append(len(out_frames))
+            out_frames.extend(sub_frames)
+            out_compression.extend([None] * len(sub_frames))
+        else:
+            num_sub_frames.append(1)
+            offsets.append(len(out_frames))
+            out_frames.append(frame)
+            out_compression.append(compression)
+    assert len(out_compression) == len(out_frames)
+
+    # Notice, in order to match msgpack's implicit convertion to tuples,
+    # we convert to tuples here as well.
+    header["split-num-sub-frames"] = tuple(num_sub_frames)
+    header["split-offsets"] = tuple(offsets)
+    header["compression"] = tuple(out_compression)
+    return header, out_frames
+
+
+def merge_and_deserialize(header, frames, deserializers=None):
+    """Merge and deserialize frames
+
+    This function is a drop-in replacement of `deserialize()` that merges
+    frames that were split by `serialize_and_split()`
+
+    See Also
+    --------
+    deserialize
+    serialize_and_split
+    """
+    merged_frames = []
+    if "split-num-sub-frames" not in header:
+        merged_frames = frames
+    else:
+        for n, offset in zip(header["split-num-sub-frames"], header["split-offsets"]):
+            if n == 1:
+                merged_frames.append(frames[offset])
+            else:
+                merged_frames.append(bytearray().join(frames[offset : offset + n]))
+
+    return deserialize(header, merged_frames, deserializers=deserializers)
+
+
 class Serialize:
     """Mark an object that should be serialized
 
@@ -431,70 +512,6 @@ class Serialized:
         return not (self == other)
 
 
-def extract_serialize(x) -> tuple:
-    """Pull out Serialize objects from message
-
-    This also remove large bytestrings from the message into a second
-    dictionary.
-
-    Examples
-    --------
-    >>> from distributed.protocol import to_serialize
-    >>> msg = {'op': 'update', 'data': to_serialize(123)}
-    >>> extract_serialize(msg)
-    ({'op': 'update'}, {('data',): <Serialize: 123>}, set())
-    """
-    typ_x: type = type(x)
-    if typ_x is dict:
-        x_d: dict = x
-        x_items = x_d.items()
-        x2 = {}
-    elif typ_x is list:
-        x_l: list = x
-        x_items = enumerate(x_l)
-        x2 = len(x_l) * [None]
-
-    ser = {}
-    bytestrings = set()
-    path = ()
-    _extract_serialize(x_items, x2, ser, bytestrings, path)
-    return x2, ser, bytestrings
-
-
-def _extract_serialize(x_items, x2, ser: dict, bytestrings: set, path: tuple) -> None:
-    for k, v in x_items:
-        path_k = path + (k,)
-        typ_v: type = type(v)
-        if typ_v is dict:
-            v_d: dict = v
-            v_items = v_d.items()
-            x2[k] = v2 = {}
-            _extract_serialize(v_items, v2, ser, bytestrings, path_k)
-        elif typ_v is list:
-            v_l: list = v
-            v_items = enumerate(v_l)
-            x2[k] = v2 = len(v_l) * [None]
-            _extract_serialize(v_items, v2, ser, bytestrings, path_k)
-        elif typ_v is Serialize or typ_v is Serialized:
-            ser[path_k] = v
-        elif typ_v is bytes:
-            v_b: bytes = v
-            if len(v_b) > 2 ** 16:
-                ser[path_k] = to_serialize(v_b)
-                bytestrings.add(path_k)
-            else:
-                x2[k] = v_b
-        elif typ_v is bytearray:
-            v_ba: bytearray = v
-            if len(v_ba) > 2 ** 16:
-                ser[path_k] = to_serialize(v_ba)
-                bytestrings.add(path_k)
-            else:
-                x2[k] = v_ba
-        else:
-            x2[k] = v
-
-
 def nested_deserialize(x):
     """
     Replace all Serialize and Serialized values nested in *x*
@@ -534,13 +551,8 @@ def nested_deserialize(x):
 
 
 def serialize_bytelist(x, **kwargs):
-    header, frames = serialize(x, **kwargs)
-    if "writeable" not in header:
-        header["writeable"] = tuple(map(is_writeable, frames))
-    if "lengths" not in header:
-        header["lengths"] = tuple(map(nbytes, frames))
+    header, frames = serialize_and_split(x, **kwargs)
     if frames:
-        frames = sum(map(frame_split_size, frames), [])
         compression, frames = zip(*map(maybe_compress, frames))
     else:
         compression = []
@@ -566,8 +578,7 @@ def deserialize_bytes(b):
     else:
         header = {}
     frames = decompress(header, frames)
-    frames = merge_frames(header, frames)
-    return deserialize(header, frames)
+    return merge_and_deserialize(header, frames)
 
 
 ################################
