@@ -1,48 +1,44 @@
 import asyncio
 import os
 import socket
-import sys
 import threading
+import warnings
 import weakref
 
 import pytest
 
 import dask
-from distributed.core import (
-    pingpong,
-    Server,
-    rpc,
-    connect,
-    send_recv,
-    coerce_to_address,
-    ConnectionPool,
-)
-from distributed.protocol.compression import compressions
 
+from distributed.core import (
+    ConnectionPool,
+    Server,
+    Status,
+    coerce_to_address,
+    connect,
+    pingpong,
+    rpc,
+    send_recv,
+)
 from distributed.metrics import time
 from distributed.protocol import to_serialize
+from distributed.protocol.compression import compressions
 from distributed.utils import get_ip, get_ipv6
+from distributed.utils_test import loop  # noqa F401
 from distributed.utils_test import (
-    gen_cluster,
-    has_ipv6,
     assert_can_connect,
-    assert_cannot_connect,
     assert_can_connect_from_everywhere_4,
     assert_can_connect_from_everywhere_4_6,
     assert_can_connect_from_everywhere_6,
     assert_can_connect_locally_4,
     assert_can_connect_locally_6,
-    tls_security,
+    assert_cannot_connect,
     captured_logger,
+    gen_cluster,
+    has_ipv6,
     inc,
     throws,
+    tls_security,
 )
-from distributed.utils_test import loop  # noqa F401
-
-
-EXTERNAL_IP4 = get_ip()
-if has_ipv6():
-    EXTERNAL_IP6 = get_ipv6()
 
 
 def echo(comm, x):
@@ -76,6 +72,55 @@ def echo_no_serialize(comm, x):
     return {"result": x}
 
 
+def test_server_status_is_always_enum():
+    """
+    Assignments with strings get converted to corresponding Enum variant
+    """
+    server = Server({})
+    assert isinstance(server.status, Status)
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter("ignore")
+        assert server.status != Status.stopped
+        server.status = "stopped"
+    assert isinstance(server.status, Status)
+    assert server.status == Status.stopped
+
+
+def test_server_status_assign_non_variant_raises():
+    server = Server({})
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter("ignore")
+        with pytest.raises(AssertionError):
+            server.status = "I do not exists"
+
+
+def test_server_status_assign_with_variant_warns():
+    server = Server({})
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter("default")
+        with pytest.warns(PendingDeprecationWarning):
+            server.status = "running"
+
+
+def test_server_status_assign_with_variant_raises_in_tests():
+    """That would be the default in user code"""
+    server = Server({})
+    with pytest.raises(PendingDeprecationWarning):
+        server.status = "running"
+
+
+def test_server_assign_assign_enum_is_quiet():
+    """That would be the default in user code"""
+    server = Server({})
+    server.status = Status.running
+
+
+def test_server_status_compare_enum_is_quiet():
+    """That would be the default in user code"""
+    server = Server({})
+    server.status == Status.running
+
+
 def test_server(loop):
     """
     Simple Server test.
@@ -134,15 +179,20 @@ class MyServer(Server):
     default_port = 8756
 
 
-@pytest.mark.skipif(
-    sys.version_info < (3, 7),
-    reason="asynccontextmanager not avaiable before Python 3.7",
-)
 @pytest.mark.asyncio
 async def test_server_listen():
     """
     Test various Server.listen() arguments and their effect.
     """
+    import socket
+
+    try:
+        EXTERNAL_IP4 = get_ip()
+        if has_ipv6():
+            EXTERNAL_IP6 = get_ipv6()
+    except socket.gaierror:
+        raise pytest.skip("no network access")
+
     from contextlib import asynccontextmanager
 
     @asynccontextmanager
@@ -269,7 +319,7 @@ async def check_rpc(listen_addr, rpc_addr=None, listen_args={}, connection_args=
         assert response == b"pong"
 
     assert not remote.comms
-    assert remote.status == "closed"
+    assert remote.status == Status.closed
 
     server.stop()
     await asyncio.sleep(0)
