@@ -1,32 +1,33 @@
 import asyncio
-from contextlib import suppress
 import os
 import random
+from contextlib import suppress
 from time import sleep
 
 import pytest
-from tlz import partition_all, first
+from tlz import first, partition_all
 
 from dask import delayed
+
 from distributed import Client, Nanny, wait
 from distributed.comm import CommClosedError
-from distributed.client import wait
+from distributed.compatibility import MACOS
 from distributed.metrics import time
-from distributed.utils import sync, CancelledError
-from distributed.utils_test import (
-    gen_cluster,
-    cluster,
-    inc,
-    div,
-    slowinc,
-    slowadd,
-    captured_logger,
-)
+from distributed.utils import CancelledError, sync
 from distributed.utils_test import loop  # noqa: F401
+from distributed.utils_test import (
+    captured_logger,
+    cluster,
+    div,
+    gen_cluster,
+    inc,
+    slowadd,
+    slowinc,
+)
 
 
 def test_submit_after_failed_worker_sync(loop):
-    with cluster(active_rpc_timeout=10, disconnect_timeout=10) as (s, [a, b]):
+    with cluster() as (s, [a, b]):
         with Client(s["address"], loop=loop) as c:
             L = c.map(inc, range(10))
             wait(L)
@@ -64,7 +65,7 @@ async def test_submit_after_failed_worker(c, s, a, b):
 
 
 def test_gather_after_failed_worker(loop):
-    with cluster(active_rpc_timeout=10, disconnect_timeout=10) as (s, [a, b]):
+    with cluster() as (s, [a, b]):
         with Client(s["address"], loop=loop) as c:
             L = c.map(inc, range(10))
             wait(L)
@@ -286,6 +287,7 @@ async def test_multiple_clients_restart(s, a, b):
     await c2.close()
 
 
+@pytest.mark.flaky(reruns=10, reruns_timeout=5, condition=MACOS)
 @gen_cluster(Worker=Nanny, timeout=60)
 async def test_restart_scheduler(s, a, b):
     import gc
@@ -384,8 +386,9 @@ async def test_worker_who_has_clears_after_failed_connection(c, s, a, b):
     await wait(futures)
 
     result = await c.submit(sum, futures, workers=a.address)
-    for dep in set(a.dep_state) - set(a.task_state):
-        a.release_dep(dep, report=True)
+    deps = [dep for dep in a.tasks.values() if dep.key not in a.data_needed]
+    for dep in deps:
+        a.release_key(dep.key, report=True)
 
     n_worker_address = n.worker_address
     with suppress(CommClosedError):
@@ -398,7 +401,7 @@ async def test_worker_who_has_clears_after_failed_connection(c, s, a, b):
     await total
 
     assert not a.has_what.get(n_worker_address)
-    assert not any(n_worker_address in s for s in a.who_has.values())
+    assert not any(n_worker_address in s for ts in a.tasks.values() for s in ts.who_has)
 
     await n.close()
 
@@ -415,16 +418,22 @@ async def test_restart_timeout_on_long_running_task(c, s, a):
     assert "timeout" not in text.lower()
 
 
+@pytest.mark.slow
 @gen_cluster(client=True, scheduler_kwargs={"worker_ttl": "500ms"})
 async def test_worker_time_to_live(c, s, a, b):
+    from distributed.scheduler import heartbeat_interval
+
+    # worker removal is also controlled by 10 * heartbeat
     assert set(s.workers) == {a.address, b.address}
+    interval = 10 * heartbeat_interval(len(s.workers)) + 0.5
+
     a.periodic_callbacks["heartbeat"].stop()
     await asyncio.sleep(0.010)
     assert set(s.workers) == {a.address, b.address}
 
     start = time()
     while set(s.workers) == {a.address, b.address}:
-        await asyncio.sleep(0.050)
-        assert time() < start + 2
+        await asyncio.sleep(interval)
+        assert time() < start + interval + 0.1
 
     set(s.workers) == {b.address}
